@@ -1,12 +1,7 @@
-import importlib
 import logging
-import pkgutil
 
 import click
 
-from devcli.context import DevCliContext
-
-
 
 @click.group()
 @click.pass_context
